/*
** Module   : LineContent.java
** Abstract : Progress 4GL INI file content simple line to ignore class
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130701 Created initial version.
*/

package com.goldencode.p2j.util;

import java.io.*;

/**
 * A class implementing the INI text file comment line or empty line. In both cases this is the
 * single line to ignore. The only we need to know is where it is located inside INI file. Can be
 * the part of the section or be the header of the file not belonging to any section.
 *
 * @author    EVL
 */
public class LineContent
extends Content
{
   /** The text associated with the line content. */
   private String text = null;
   
   /**
    * Constructs an instance of the ignored line in INI file. Just calls case constructor.
    *
    * @param text 
    *        The text corresponding to the whole line of the comment or empty space line.
    */
   public LineContent(String text)
   {
      super();
      this.text = text;
   }
   
   /**
    * Writes the content to the file via Writer object provided.
    * 
    * @param pw 
    *        The writer will be used to save content to the file.
    */
   public void write(PrintWriter pw)
   {
      pw.println(text);
   }
   
   /**
    * Checks if the content is empty or not.
    * 
    * @return <code>true</code> in case of not emptry, <code>false</code> otherwise.
    */
   public boolean notEmpty()
   {
      return text != null;
   }
}
